﻿# This is not part of the TODCM open source project.
# This is a tool provided by Tiller Software Co., Ltd. to perform bulk data import into TODCM
# Tiller Software Co., Ltd. is not responsible for any data corruption resulted from running this script.
#
# This script imports a set of data for one department
# You have to make sure the CSV file names in each of the load data statements are correct below
# The CSV file has to be UNIX file format and DOS format will not work unless you change the line termintaion character
# CSV fields should delimited by '$' and text data should be enclosed by '^'. You can change these chars to fit your needs
# You have to keep the titles in the first line of the CSV file since the data load always ignores the first line
# Without the first line titles the first data row will be ignored

# The department id has to be changed accordingly
SET @departmentid = 1;

# type is always 11
SET @type = 11;
SET @enable = 1;

drop table if exists import_strand_tmp;
drop table if exists import_standard_tmp;
drop table if exists import_benchmark_tmp;

create table import_strand_tmp (
	strand_code varchar(20),
	strand varchar(5000),
	id int AUTO_INCREMENT,
  PRIMARY KEY (`id`)
) ENGINE=MyISAM;

create table import_standard_tmp (
	strand_code varchar(20),
	standard_code varchar(20),
	standard varchar(5000),
	id int AUTO_INCREMENT,
  PRIMARY KEY (`id`)
) ENGINE=MyISAM;

create table import_benchmark_tmp (
	standard_code varchar(20),
	bench_code varchar(20),
	min_grade varchar(20),
	max_grade varchar(20),
	benchmark varchar(5000),
	id int AUTO_INCREMENT,
  PRIMARY KEY (`id`)
) ENGINE=MyISAM;

# Loads the strand CSV into a tmp table
# Change strand.csv to your filename or use the same filename
# Use $ and ^ in CSV
load data local infile 'strand.csv' into table import_strand_tmp
   fields terminated by '$'
   enclosed by '^'
   lines terminated by '\n'
   IGNORE 1 LINES;

# Loads the standard CSV file into a tmp table
load data local infile 'standard.csv' into table import_standard_tmp
   fields terminated by '$'
   enclosed by '^'
   lines terminated by '\n'
   IGNORE 1 LINES;

# Loads the benchmark CSV into a tmp table
load data local infile 'benchmark.csv' into table import_benchmark_tmp
   fields terminated by '$'
   enclosed by '^'
   lines terminated by '\n'
   IGNORE 1 LINES;

update import_strand_tmp set strand_code=trim(strand_code);
update import_strand_tmp set strand=trim(strand);
update import_standard_tmp set strand_code=trim(strand_code);
update import_standard_tmp set standard_code=trim(standard_code);
update import_standard_tmp set standard=trim(standard);
update import_benchmark_tmp set standard_code=trim(standard_code);
update import_benchmark_tmp set bench_code=trim(bench_code);
update import_benchmark_tmp set min_grade=trim(min_grade);
update import_benchmark_tmp set max_grade=trim(max_grade);
update import_benchmark_tmp set benchmark=trim(benchmark);

insert into strand (data,departmentid,type,enabled,importid)
(select strand, @departmentid,@type, @enable, strand_code from import_strand_tmp);

insert into standard (data,importid,type,enabled,strandid)
(select standard, standard_code,@type, @enable,s.id
 from import_standard_tmp i
 join strand s ON s.importid = i.strand_code);

insert into benchmark (data,importid,type,enabled,standardid,mingradeid,maxgradeid)
(select benchmark, bench_code, @type, @enable, s.id,
    (select id from grade g1 where g1.sort = it.min_grade),
    (select id from grade g2 where g2.sort = it.max_grade)
 from import_benchmark_tmp it
 join standard s on s.importid=it.standard_code);

#### Delete tmp table
drop table import_strand_tmp;
drop table import_standard_tmp;
drop table import_benchmark_tmp;